<?php
/**
 * Plugin Name:  BuddyPress Friendship Restrictions
 * Plugin URI:   https://buddydev.com/plugins/buddypress-friendship-restrictions/
 * Description:  An addon for BuddyPress that enable site admin to restrict user for friendship module.
 * Version:      1.1.5
 * Author:       BuddyDev Team
 * Author URI:   https://buddydev.com/
 * License:      GPL2
 * License URI:  https://www.gnu.org/licenses/gpl-2.0.html
 * Domain Path:  /languages
 **/

/**
 * @author Ravi Sharma(raviousprime), Brajesh Singh
 */

use BP_Friendship_Restrictions\Bootstrap\Autoloader;
use BP_Friendship_Restrictions\Bootstrap\Bootstrapper;

// Exit if file accessed directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class BP_Friendship_Restrictions_Helper
 *
 * @property-read $version Plugin version.
 * @property-read $path Plugin directory path.
 * @property-read $url Plugin directory url.
 */
class BP_Friendship_Restrictions_Helper {

	/**
	 * Plugin version
	 *
	 * @var string
	 */
	private $version = '1.1.5';

	/**
	 * Class instance
	 *
	 * @var BP_Friendship_Restrictions_Helper
	 */
	private static $instance = null;

	/**
	 * Plugin directory absolute path
	 *
	 * @var string
	 */
	private $path;

	/**
	 * Protected properties
	 *
	 * @var array
	 */
	private $guarded = array( 'instance' );

	/**
	 * The constructor.
	 */
	private function __construct() {

		$this->path = plugin_dir_path( __FILE__ );

		$this->bootstrap();
		$this->setup();
	}

	/**
	 * Class instance
	 *
	 * @return BP_Friendship_Restrictions_Helper
	 */
	public static function get_instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Boot
	 */
	private function bootstrap() {
		// Load autoloader.
		require_once $this->path . 'src/bootstrap/class-autoloader.php';
		// Register autoloader.
		spl_autoload_register( new Autoloader( 'BP_Friendship_Restrictions\\', __DIR__ . '/src/' ) );
	}

	/**
	 * Initialize bootstrapper class
	 */
	public function setup() {
		register_activation_hook( __FILE__, array( $this, 'activate' ) );
		Bootstrapper::boot();
	}

	/**
	 * Update settings on plugin activation.
	 */
	public function activate() {
		require_once $this->path . 'src/core/bp-friendship-restrictions-functions.php';
		$settings = bpf_restrictions_get_default_settings();

		$setting_name = 'bp_friendship_restrictions_settings';

		if ( ! get_option( $setting_name ) ) {
			update_option( $setting_name, $settings );
		}

		// in case of multisite, let us save the default settings in site meta
		// (in case site admin plans to use it as network active).
		if ( is_multisite() && ! get_site_option( $setting_name ) ) {
			update_site_option( $setting_name, $settings );
		}
	}

	/**
	 * Get class properties
	 *
	 * @param string $key Property name.
	 *
	 * @return string|null
	 */
	public function __get( $key ) {

		if ( ! in_array( $key, $this->guarded ) && property_exists( $this, $key ) ) {
			return $this->{$key};
		}

		return null;
	}
}

/**
 * Return class instance
 *
 * @return BP_Friendship_Restrictions_Helper
 */
function bp_friendship_restrictions() {
	return BP_Friendship_Restrictions_Helper::get_instance();
}

bp_friendship_restrictions();
