<?php
/**
 * Bootstrapper. Initializes the plugin.
 *
 * @package    BuddyPress Friendship Restrictions
 * @subpackage Bootstrap
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

namespace BP_Friendship_Restrictions\Bootstrap;

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

use BP_Friendship_Restrictions\Admin\Admin_Helper;
use BP_Friendship_Restrictions\Handlers\Ajax_Request_Handler;
use BP_Friendship_Restrictions\Handlers\Hooks_Helper;
use BP_Friendship_Restrictions\Handlers\Actions_Handler;

/**
 * Bootstrapper.
 */
class Bootstrapper {

	/**
	 * Setup the bootstrapper.
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Bind hooks
	 */
	private function setup() {
		add_action( 'plugins_loaded', array( $this, 'load' ) );
		add_action( 'plugins_loaded', array( $this, 'admin_load' ), 9996 ); // pt-settings 1.0.4
		add_action( 'init', array( $this, 'load_translations' ) );
	}

	/**
	 * Load core functions/template tags.
	 * These are non auto loadable constructs.
	 */
	public function load() {

		require_once bp_friendship_restrictions()->path . 'src/core/bp-friendship-restrictions-functions.php';

		Ajax_Request_Handler::boot();
		Hooks_Helper::boot();
		Actions_Handler::boot();
	}

	/**
	 * Load admin
	 */
	public function admin_load() {

		if ( ! is_admin() || defined( 'DOING_AJAX' ) ) {
			return;
		}

		// Load pt-settings.
		require_once bp_friendship_restrictions()->path . 'src/admin/pt-settings/pt-settings-loader.php';

		Admin_Helper::boot();
	}

	/**
	 * Load translations.
	 */
	public function load_translations() {
		load_plugin_textdomain(
			'buddypress-friendship-restrictions',
			false,
			basename( bp_friendship_restrictions()->path ) . '/languages'
		);
	}
}
