<?php
/**
 * Hooks Helper
 *
 * @package    BP_Friendship_Restrictions
 * @subpackage Handlers
 * @copyright  Copyright (c) 2018, BuddyDev
 */

namespace BP_Friendship_Restrictions\Handlers;

// Exit if files accessed directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Hooks_Helper
 */
class Hooks_Helper {

	/**
	 * Boot class
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * The constructor.
	 */
	private function setup() {
		add_filter( 'bp_get_add_friend_button', array( $this, 'maybe_disable_button' ) );
	}

	/**
	 * Disable button if needed.
	 *
	 * @param array $button Button array.
	 *
	 * @return array
	 */
	public function maybe_disable_button( $button ) {

		if ( is_super_admin() ) {
			return $button;
		}

		// Id not given, something else filtered it.
		if ( empty( $button['id'] ) ) {
			return $button;
		}

		$button_id = $button['id'];
		$friend_id = absint( str_replace( 'friendship-button-', '', $button['wrapper_id'] ) );

		switch ( $button_id ) {

			case 'is_friend':
				if ( bpf_restrictions_is_unfriending_disabled() ) {
					$button = array();
				}

				break;
			case 'not_friends':
				if ( ! bpf_restrictions_user_is_valid_sender( bp_loggedin_user_id(), $friend_id ) ) {
					$button = array();
				}
				break;
		}


		return $button;
	}
}